
/* Generated data (by glib-mkenums) */

#ifndef CAMEL_ENUMTYPES_H
#define CAMEL_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/camel/camel-enums.h" */

#define CAMEL_TYPE_AUTHENTICATION_RESULT	(camel_authentication_result_get_type())
GType camel_authentication_result_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_FOLDER_FLAGS	(camel_folder_flags_get_type())
GType camel_folder_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_FOLDER_INFO_FLAGS	(camel_folder_info_flags_get_type())
GType camel_folder_info_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_MIME_FILTER_TO_HTML_FLAGS	(camel_mime_filter_to_html_flags_get_type())
GType camel_mime_filter_to_html_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_STORE_INFO_FLAGS	(camel_store_info_flags_get_type())
GType camel_store_info_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_FETCH_HEADERS_TYPE	(camel_fetch_headers_type_get_type())
GType camel_fetch_headers_type_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_JUNK_STATUS	(camel_junk_status_get_type())
GType camel_junk_status_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_MIME_FILTER_BASIC_TYPE	(camel_mime_filter_basic_type_get_type())
GType camel_mime_filter_basic_type_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_MIME_FILTER_CRLF_DIRECTION	(camel_mime_filter_crlf_direction_get_type())
GType camel_mime_filter_crlf_direction_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_MIME_FILTER_CRLF_MODE	(camel_mime_filter_crlf_mode_get_type())
GType camel_mime_filter_crlf_mode_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_MIME_FILTER_GZIP_MODE	(camel_mime_filter_gzip_mode_get_type())
GType camel_mime_filter_gzip_mode_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_MIME_FILTER_YENC_DIRECTION	(camel_mime_filter_yenc_direction_get_type())
GType camel_mime_filter_yenc_direction_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_NETWORK_SECURITY_METHOD	(camel_network_security_method_get_type())
GType camel_network_security_method_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_PROVIDER_CONF_TYPE	(camel_provider_conf_type_get_type())
GType camel_provider_conf_type_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_PROVIDER_FLAGS	(camel_provider_flags_get_type())
GType camel_provider_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_PROVIDER_TYPE	(camel_provider_type_get_type())
GType camel_provider_type_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_SASL_ANON_TRACE_TYPE	(camel_sasl_anon_trace_type_get_type())
GType camel_sasl_anon_trace_type_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_SERVICE_CONNECTION_STATUS	(camel_service_connection_status_get_type())
GType camel_service_connection_status_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_SESSION_ALERT_TYPE	(camel_session_alert_type_get_type())
GType camel_session_alert_type_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_SORT_TYPE	(camel_sort_type_get_type())
GType camel_sort_type_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_STORE_FLAGS	(camel_store_flags_get_type())
GType camel_store_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_STORE_GET_FOLDER_INFO_FLAGS	(camel_store_get_folder_info_flags_get_type())
GType camel_store_get_folder_info_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_STORE_PERMISSION_FLAGS	(camel_store_permission_flags_get_type())
GType camel_store_permission_flags_get_type	(void) G_GNUC_CONST;

#define CAMEL_TYPE_TRANSFER_ENCODING	(camel_transfer_encoding_get_type())
GType camel_transfer_encoding_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* CAMEL_ENUMTYPES_H */

/* Generated data ends here */

