
/* Generated data (by glib-mkenums) */

#ifndef E_BOOK_ENUMTYPES_H
#define E_BOOK_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/addressbook/libebook/e-book-types.h" */

#define E_TYPE_BOOK_STATUS	(e_book_status_get_type())
GType e_book_status_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_BOOK_ENUMTYPES_H */

/* Generated data ends here */

