
/* Generated data (by glib-mkenums) */

#ifndef E_CAL_ENUMTYPES_H
#define E_CAL_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/calendar/libecal/e-cal-types.h" */

#define E_TYPE_CAL_CLIENT_SOURCE_TYPE	(e_cal_client_source_type_get_type())
GType e_cal_client_source_type_get_type	(void) G_GNUC_CONST;

#define E_TYPE_CAL_OBJ_MOD_TYPE	(e_cal_obj_mod_type_get_type())
GType e_cal_obj_mod_type_get_type	(void) G_GNUC_CONST;

#define E_TYPE_CAL_CHANGE_TYPE	(e_cal_change_type_get_type())
GType e_cal_change_type_get_type	(void) G_GNUC_CONST;

#define E_TYPE_CALENDAR_STATUS	(e_calendar_status_get_type())
GType e_calendar_status_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DATA_CAL_OBJ_TYPE	(e_data_cal_obj_type_get_type())
GType e_data_cal_obj_type_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DATA_CAL_OBJ_MOD_TYPE	(e_data_cal_obj_mod_type_get_type())
GType e_data_cal_obj_mod_type_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_CAL_ENUMTYPES_H */

/* Generated data ends here */

