
/* Generated data (by glib-mkenums) */

#ifndef E_BACKEND_ENUMTYPES_H
#define E_BACKEND_ENUMTYPES_H

#include <glib-object.h>

G_BEGIN_DECLS

/* Enumerations from "/usr/src/ports/evolution-data-server/evolution-data-server-3.20.6-1.x86_64/src/evolution-data-server-3.20.6/libebackend/e-backend-enums.h" */

#define E_TYPE_AUTHENTICATION_SESSION_RESULT	(e_authentication_session_result_get_type())
GType e_authentication_session_result_get_type	(void) G_GNUC_CONST;

#define E_TYPE_DBUS_SERVER_EXIT_CODE	(e_dbus_server_exit_code_get_type())
GType e_dbus_server_exit_code_get_type	(void) G_GNUC_CONST;

#define E_TYPE_SOURCE_PERMISSION_FLAGS	(e_source_permission_flags_get_type())
GType e_source_permission_flags_get_type	(void) G_GNUC_CONST;

G_END_DECLS

#endif /* E_BACKEND_ENUMTYPES_H */

/* Generated data ends here */

